@@ -40,7 +40,7 @@
 #include "sumpt.h"
 #include "utils.h"
 
-       const char* const svnRevisionBayesC = "$Rev: 1008 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
+       const char* const svnRevisionBayesC = "$Rev: 1068 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
 extern const char* const svnRevisionBestC;
 extern const char* const svnRevisionCommandC;
 extern const char* const svnRevisionLikeliC;
@@ -570,7 +570,8 @@ int InitializeMrBayes (void)
     
     /* Prior model settings */
     defaultModel.dataType = DNA;                        /* datatype                                     */
-    strcpy(defaultModel.coding, "All");                 /* ascertainment bias                           */
+    defaultModel.coding = 0;                            /* ascertainment bias                           */
+    strcpy(defaultModel.codingString, "All");           /* ascertainment bias string                    */
     strcpy(defaultModel.nucModel, "4by4");              /* nucleotide model                             */
     strcpy(defaultModel.nst, "1");                      /* number of substitution types                 */
     strcpy(defaultModel.aaModelPr, "Fixed");            /* amino acid model prior                       */
@@ -724,10 +725,10 @@ int InitializeMrBayes (void)
     defaultModel.clockRateExp = 1.0;
     defaultModel.clockRateFix = 1.0;
     strcpy(defaultModel.speciationPr, "Exponential");   /* prior on speciation rate (net diversification) */
-    defaultModel.speciationFix = 1.0;
+    defaultModel.speciationFix = 0.1;
     defaultModel.speciationUni[0] = 0.0;
     defaultModel.speciationUni[1] = 10.0;
-    defaultModel.speciationExp = 1.0;
+    defaultModel.speciationExp = 10.0;
     strcpy(defaultModel.extinctionPr, "Beta");          /* prior on extinction rate (turnover)          */
     defaultModel.extinctionFix = 0.5;
     defaultModel.extinctionBeta[0] = 1;
@@ -986,7 +987,7 @@ int ReinitializeMrBayes (void)
     /* comparetree parameters */
     strcpy(comptreeParams.comptFileName1, "temp.t"); /* input name for comparetree command            */
     strcpy(comptreeParams.comptFileName2, "temp.t"); /* input name for comparetree command            */
-    strcpy(comptreeParams.comptOutfile, "temp.comp");/* input name for comparetree command            */
+    strcpy(comptreeParams.comptOutfile, "temp.comp");/* output name for comparetree command           */
     comptreeParams.minPartFreq = 0.0;                /* minimum frequency of partitions to include    */
 
     /* plot parameters */
