@@ -37,9 +37,9 @@
 /* uncomment the following line when releasing, also modify the VERSION_NUMBER below */
 #define RELEASE
 #ifdef RELEASE
-#define VERSION_NUMBER  "3.2.5"
+#define VERSION_NUMBER  "3.2.6"
 #else
-#define VERSION_NUMBER  "3.2.6-svn"
+#define VERSION_NUMBER  "3.2.7-svn"
 #endif
 
 #if !defined (UNIX_VERSION) && !defined (WIN_VERSION) && !defined (MAC_VERSION)
@@ -240,6 +240,7 @@ typedef float CLFlt;        /* single-precision float used for cond likes (CLFlt
 #define RIGHTCURL               26
 #define DOLLAR                  27
 #define AMPERSAND               28
+#define VERTICALBAR             29
 
 #define MAX_Q_RATE              100.0f
 #define MIN_SHAPE_PARAM         0.00001f
@@ -446,6 +447,18 @@ enum ConstraintType
     HARD
     };
 
+enum CodingType
+    {
+    ALL                 = 0,
+    NOABSENCESITES      = 1,
+    NOPRESENCESITES     = 2,
+    VARIABLE            = 3,
+    NOSINGLETONPRESENCE = 4,
+    NOSINGLETONABSENCE  = 8,
+    NOSINGLETONS        = 12,
+    INFORMATIVE         = 15
+    };
+
 /* typedef for calibration */
 typedef struct calibration
     {
@@ -901,7 +914,8 @@ typedef struct model
     char        nst[100];          /* number of substitution types                 */
     char        parsModel[100];    /* use the (so-called) parsimony model          */
     char        geneticCode[100];  /* genetic code used                            */
-    char        coding[100];       /* type of patterns encoded                     */
+    int         coding;            /* type of patterns encoded                     */
+    char        codingString[100]; /* string describing type of patterns encoded   */
     char        ploidy[100];       /* ploidy level                                 */
     char        omegaVar[100];     /* type of omega variation model                */
     char        ratesModel[100];   /* rates across sites model                     */
@@ -1419,6 +1433,7 @@ typedef struct charinfo
     int cType;
     int nStates;
     int constant[10];
+    int singleton[10];
     int variable;
     int informative;
     } CharInfo;
