@@ -35,7 +35,7 @@
 #include "model.h"
 #include "utils.h"
 
-const char* const svnRevisionMbbeagleC = "$Rev: 906 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
+const char* const svnRevisionMbbeagleC = "$Rev: 1008 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
 
 /* Functions and variables defined in mcmc.c that are not exported in mcmc.h */
 void    LaunchLogLikeForDivision(int chain, int d, MrBFlt* lnL);
@@ -43,18 +43,13 @@ void    LaunchLogLikeForDivision(int chain, int d, MrBFlt* lnL);
 void    FlipCondLikeSpace (ModelInfo *m, int chain, int nodeIndex);
 void    FlipNodeScalerSpace (ModelInfo *m, int chain, int nodeIndex);
 void    FlipSiteScalerSpace (ModelInfo *m, int chain);
+void    FlipTiProbsSpace (ModelInfo *m, int chain, int nodeIndex);
 void    ResetSiteScalers (ModelInfo *m, int chain);
 void    CopySiteScalers (ModelInfo *m, int chain);
 
-int     TreeCondLikes_Beagle (Tree *t, int division, int chain);
-int     TreeLikelihood_Beagle (Tree *t, int division, int chain, MrBFlt *lnL, int whichSitePats);
-int     TreeTiProbs_Beagle (Tree *t, int division, int chain);
-
 int     TreeCondLikes_Beagle_No_Rescale (Tree *t, int division, int chain);
 int     TreeCondLikes_Beagle_Rescale_All (Tree *t, int division, int chain);
 
-void    FlipTiProbsSpace (ModelInfo *m, int chain, int nodeIndex);
-
 extern int *chainId;
 extern int numLocalChains;
 
@@ -237,8 +232,8 @@ void LaunchBEAGLELogLikeForDivision(int chain, int d, ModelInfo* m, Tree* tree,
         if (m->upDateAll == YES) {
             for (i=0; i<m->nCijkParts; i++) {           
                 beagleResetScaleFactors(m->beagleInstance, m->siteScalerIndex[chain] + i);
+                }
             }
-        }
         else
             CopySiteScalers(m, chain);
 
@@ -255,7 +250,7 @@ void LaunchBEAGLELogLikeForDivision(int chain, int d, ModelInfo* m, Tree* tree,
         if (m->succesCount[chain] > 1000)
             {
             m->succesCount[chain] = 10;
-            m->rescaleFreq[chain]++; /* increase rescaleFreq independent of whether we accept or reject new state*/
+            m->rescaleFreq[chain]++; /* increase rescaleFreq independent of whether we accept or reject new state */
             m->rescaleFreqOld = rescaleFreqNew = m->rescaleFreq[chain];
             for (i=0; i<tree->nIntNodes; i++)
                 {
@@ -277,7 +272,8 @@ void LaunchBEAGLELogLikeForDivision(int chain, int d, ModelInfo* m, Tree* tree,
                 {
                 p = tree->intDownPass[i];
                 if (p->upDateCl == YES) {
-                     /* flip to the new workspace since TreeCondLikes_Beagle_Rescale_All() does not do it for (p->upDateCl == YES) since it assumes that TreeCondLikes_Beagle_No_Rescale() did it*/
+                     /* flip to the new workspace since TreeCondLikes_Beagle_Rescale_All() does not do it for
+                        (p->upDateCl == YES) since it assumes that TreeCondLikes_Beagle_No_Rescale() did it */
                     FlipCondLikeSpace (m, chain, p->index);
                    }
                 }
@@ -296,16 +292,16 @@ void LaunchBEAGLELogLikeForDivision(int chain, int d, ModelInfo* m, Tree* tree,
                     {
                     if (m->succesCount[chain] < 4)
                         {
-                        rescaleFreqNew-= rescaleFreqNew >> 3; /* <== we cut up to 12,5% of rescaleFreq */
+                        rescaleFreqNew -= rescaleFreqNew >> 3; /* <== we cut up to 12,5% of rescaleFreq */
                         if (m->succesCount[chain] < 2)
                             {
-                            rescaleFreqNew-= rescaleFreqNew >> 3;
+                            rescaleFreqNew -= rescaleFreqNew >> 3;
                             /* to avoid situation when we may stack at high rescaleFreq when new states do not get accepted because of low liklihood but there proposed frequency is high we reduce rescaleFreq even if we reject the last move*/
                             /* basically the higher probability of proposing of low liklihood state which needs smaller rescaleFreq would lead to higher probability of hitting this code which should reduce rescaleFreqOld thus reduce further probability of hitting this code */
                             /* at some point this negative feedback mechanism should get in balance with the mechanism of periodically increasing rescaleFreq when long sequence of successes is achieved*/
-                            m->rescaleFreqOld-= m->rescaleFreqOld >> 3;
+                            m->rescaleFreqOld -= m->rescaleFreqOld >> 3;
                             }
-                        m->rescaleFreqOld-= m->rescaleFreqOld >> 3;
+                        m->rescaleFreqOld -= m->rescaleFreqOld >> 3;
                         m->rescaleFreqOld--;
                         m->rescaleFreqOld = (m->rescaleFreqOld ? m->rescaleFreqOld:1);
                         m->recalculateScalers = YES; 
@@ -313,7 +309,7 @@ void LaunchBEAGLELogLikeForDivision(int chain, int d, ModelInfo* m, Tree* tree,
                         }
                     }
                 rescaleFreqNew--;
-                rescaleFreqNew = (rescaleFreqNew ? rescaleFreqNew:1);
+                rescaleFreqNew = (rescaleFreqNew ? rescaleFreqNew : 1);
                 }
             m->succesCount[chain] = 0;
     rescale_all:
@@ -336,21 +332,21 @@ void LaunchBEAGLELogLikeForDivision(int chain, int d, ModelInfo* m, Tree* tree,
                 {
                 if (rescaleFreqNew > 1)
                     {
-                    /*Swap back scalers which were  swapped in TreeCondLikes_Beagle_Rescale_All() */
+                    /* Swap back scalers which were swapped in TreeCondLikes_Beagle_Rescale_All() */
                     for (i=0; i<tree->nIntNodes; i++)
                         {
                         p = tree->intDownPass[i];
                         if (isScalerNode[p->index] == YES)
                             FlipNodeScalerSpace (m, chain, p->index);
                         }
-                    rescaleFreqNew -= rescaleFreqNew >> 3; /*<== we cut up to 12,5% of rescaleFreq */
+                    rescaleFreqNew -= rescaleFreqNew >> 3; /* <== we cut up to 12,5% of rescaleFreq */
                     rescaleFreqNew--;                      /* we cut extra 1 of rescaleFreq */
                     goto while_loop;
                     }
                 }
-             m->rescaleFreq[chain] =  rescaleFreqNew;
-        }               
-    }
+            m->rescaleFreq[chain] = rescaleFreqNew;
+            }
+        }
     
     /* Count number of evaluations */
     m->beagleComputeCount[chain]++;
@@ -417,7 +413,7 @@ void BeagleRemoveGPUDevicesFromList(int **beagleResource, int *beagleResourceCou
 | BeaglePrintResources: outputs the available BEAGLE resources
 |
 ----------*/
-void BeaglePrintResources() 
+void BeaglePrintResources()
 {
     int i;
     BeagleResourceList* beagleResources;
@@ -971,9 +967,9 @@ int TreeLikelihood_Beagle (Tree *t, int division, int chain, MrBFlt *lnL, int wh
 
     /* find category frequencies */
     if (hasPInvar == NO)
-        freq =  1.0 /  m->numGammaCats;
+        freq = 1.0 / m->numGammaCats;
     else
-        freq = (1.0 - pInvar) /  m->numGammaCats;
+        freq = (1.0 - pInvar) / m->numGammaCats;
 
     /* TODO: cat weights only need to be set when they change */
     /* set category frequencies in beagle instance */
@@ -1061,13 +1057,13 @@ int TreeLikelihood_Beagle (Tree *t, int division, int chain, MrBFlt *lnL, int wh
     countALL++;
 #   endif
     if (beagleReturn == BEAGLE_ERROR_FLOATING_POINT)
-    {
+        {
 #   if defined (MB_PRINT_DYNAMIC_RESCALE_FAIL_STAT)
         countBeagleDynamicFail++;
         MrBayesPrint ("DEBUG INFO (not an error) countBeagleDynamicFail:%d countALL:%d\n", countBeagleDynamicFail, countALL);
 #   endif
         return beagleReturn;
-    }
+        }
     assert (beagleReturn == BEAGLE_SUCCESS);
     m->succesCount[chain]++;
     
@@ -1158,7 +1154,7 @@ int TreeTiProbs_Beagle (Tree *t, int division, int chain)
 
     /* get rate multipliers (for gamma & partition specific rates) */
     theRate = 1.0;
-    baseRate =  GetRate (division, chain);
+    baseRate = GetRate (division, chain);
     
     /* compensate for invariable sites if appropriate */
     if (m->pInvar != NULL)
@@ -1240,7 +1236,7 @@ int TreeTiProbs_Beagle (Tree *t, int division, int chain)
             for (j=0; j<count; j++)
                 m->tiProbIndices[j]++;
             }
-    }
+        }
 
     /* return success */
     return NO_ERROR;
